==> core-react-0.8.0.tgz: package/es/Form/FormItem/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import invariant from 'invariant';
import Icon from '../../Icon';


var FormItem = /*#__PURE__*/function (_Component) {
  _inherits(FormItem, _Component);

  function FormItem() {
    var _this;

    _classCallCheck(this, FormItem);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(FormItem).call(this));
    _this.state = {
      error: null
    };
    return _this;
  }

  _createClass(FormItem, [{
    key: "getChildContext",
    value: function getChildContext() {
      return {
        formItem: this
      };
    }
  }, {
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps() {
      var value = this.context.form.getItemValue(this);

      if (this.value !== value) {
        this.validate(value);
        this.value = value;
      }
    }
  }, {
    key: "componentWillMount",
    value: function componentWillMount() {
      this.context.form.addItem(this);
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.context.form.removeItem(this);
    }
    /**
     * @public
     * @name this.refs.formItem.validate
     * @param  {*} value 待验证字段的数据
     * @return {boolean} 成功/失败
     * @description 单个字段验证
     */

  }, {
    key: "validate",
    value: function validate(value) {
      var rules = this.context.form.props.rules;
      var rule = rules && rules[this.props.name];
      var isValid = true;

      if (rule) {
        var error = rule(value);

        if (error && typeof error === 'string') {
          isValid = false;
        }

        this.setState({
          error: error
        });
      }

      return isValid;
    }
  }, {
    key: "render",
    value: function render() {
      var error = this.state.error;

      var _this$props = this.props,
          children = _this$props.children,
          className = _this$props.className,
          name = _this$props.name,
          multiple = _this$props.multiple,
          required = _this$props.required,
          help = _this$props.help,
          label = _this$props.label,
          other = _objectWithoutProperties(_this$props, ["children", "className", "name", "multiple", "required", "help", "label"]);

      if (multiple) {
        invariant(Array.isArray(this.context.form.state.data[name]), "The value type of 'FormItem' which you set 'multiple' should be 'Array', check the 'Form data.".concat(name, "'."));
      }

      var labelWidth = this.context.form.props.labelWidth;
      var Help = help && React.createElement("div", {
        className: "".concat("waui", "-form__item-tip")
      }, React.createElement(Icon, {
        type: "question-circle"
      }), help);
      var Error = error && React.createElement("div", {
        className: "".concat("waui", "-form__item-tip")
      }, React.createElement(Icon, {
        type: "info-circle"
      }), error);
      var classNames = cx("".concat("waui", "-form__item"), _defineProperty({}, "".concat("waui", "-form__item_error"), error), className);
      return React.createElement("div", _extends({
        className: classNames
      }, other), label && React.createElement("div", {
        className: cx("".concat("waui", "-form__item-label"), _defineProperty({}, "".concat("waui", "-form__item-label_required"), required)),
        style: {
          width: "".concat(labelWidth, "px")
        }
      }, label), React.createElement("div", {
        className: "".concat("waui", "-form__item-content")
      }, children, Error || Help));
    }
  }]);

  return FormItem;
}(Component);

FormItem.contextTypes = {
  form: PropTypes.object
}; // For FormInput, FormSelect...

FormItem.childContextTypes = {
  formItem: PropTypes.instanceOf(FormItem)
};
FormItem.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,
  // 表单数据 key，与 data、rules 对应
  name: PropTypes.string.isRequired,
  // label 显示内容
  label: PropTypes.string,
  // 是否必填，label 显示上的区别
  required: PropTypes.bool,
  // 提示信息
  help: PropTypes.string,
  // 是否多条，用于一个 name 对应多个 FormItem 场景，即 name 属性对应的字段要求数组格式
  multiple: PropTypes.bool
};
export default FormItem;

==> core-react-0.8.2.tgz: package/es/Form/FormItem/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import invariant from 'invariant';
import Icon from '../../Icon';


var FormItem = /*#__PURE__*/function (_Component) {
  _inherits(FormItem, _Component);

  function FormItem() {
    var _this;

    _classCallCheck(this, FormItem);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(FormItem).call(this));
    _this.state = {
      error: null
    };
    return _this;
  }

  _createClass(FormItem, [{
    key: "getChildContext",
    value: function getChildContext() {
      return {
        formItem: this
      };
    }
  }, {
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps() {
      var value = this.context.form.getItemValue(this);

      if (this.value !== value) {
        this.validate(value);
        this.value = value;
      }
    }
  }, {
    key: "componentWillMount",
    value: function componentWillMount() {
      this.context.form.addItem(this);
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.context.form.removeItem(this);
    }
    /**
     * @public
     * @name this.refs.formItem.validate
     * @param  {*} value 待验证字段的数据
     * @return {boolean} 成功/失败
     * @description 单个字段验证
     */

  }, {
    key: "validate",
    value: function validate(value) {
      var rules = this.context.form.props.rules;
      var rule = rules && rules[this.props.name];
      var isValid = true;

      if (rule) {
        var error = rule(value);

        if (error && typeof error === 'string') {
          isValid = false;
        }

        this.setState({
          error: error
        });
      }

      return isValid;
    }
  }, {
    key: "render",
    value: function render() {
      var error = this.state.error;

      var _this$props = this.props,
          children = _this$props.children,
          className = _this$props.className,
          name = _this$props.name,
          multiple = _this$props.multiple,
          required = _this$props.required,
          help = _this$props.help,
          label = _this$props.label,
          other = _objectWithoutProperties(_this$props, ["children", "className", "name", "multiple", "required", "help", "label"]);

      if (multiple) {
        invariant(Array.isArray(this.context.form.state.data[name]), "The value type of 'FormItem' which you set 'multiple' should be 'Array', check the 'Form data.".concat(name, "'."));
      }

      var labelWidth = this.context.form.props.labelWidth;
      var Help = help && /*#__PURE__*/React.createElement("div", {
        className: "".concat("waui", "-form__item-tip")
      }, /*#__PURE__*/React.createElement(Icon, {
        type: "question-circle"
      }), help);
      var Error = error && /*#__PURE__*/React.createElement("div", {
        className: "".concat("waui", "-form__item-tip")
      }, /*#__PURE__*/React.createElement(Icon, {
        type: "info-circle"
      }), error);
      var classNames = cx("".concat("waui", "-form__item"), _defineProperty({}, "".concat("waui", "-form__item_error"), error), className);
      return (/*#__PURE__*/React.createElement("div", _extends({
          className: classNames
        }, other), label && /*#__PURE__*/React.createElement("div", {
          className: cx("".concat("waui", "-form__item-label"), _defineProperty({}, "".concat("waui", "-form__item-label_required"), required)),
          style: {
            width: "".concat(labelWidth, "px")
          }
        }, label), /*#__PURE__*/React.createElement("div", {
          className: "".concat("waui", "-form__item-content")
        }, children, Error || Help))
      );
    }
  }]);

  return FormItem;
}(Component);

FormItem.contextTypes = {
  form: PropTypes.object
}; // For FormInput, FormSelect...

FormItem.childContextTypes = {
  formItem: PropTypes.instanceOf(FormItem)
};
FormItem.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,
  // 表单数据 key，与 data、rules 对应
  name: PropTypes.string.isRequired,
  // label 显示内容
  label: PropTypes.string,
  // 是否必填，label 显示上的区别
  required: PropTypes.bool,
  // 提示信息
  help: PropTypes.string,
  // 是否多条，用于一个 name 对应多个 FormItem 场景，即 name 属性对应的字段要求数组格式
  multiple: PropTypes.bool
};
export default FormItem;
